@@ -11,7 +11,7 @@ import datetime
 from peewee import (SQL, AutoField, BigIntegerField, BooleanField,
                     DateTimeField, DeferredThroughModel, DoubleField,
                     FloatField, ForeignKeyField, IntegerField,
-                    SmallIntegerField, TextField)
+                    SmallIntegerField, TextField, fn, UUIDField)
 from playhouse.postgres_ext import ArrayField
 
 from .. import BaseModel
@@ -103,6 +103,27 @@ class Field(TargetdbBase):
         table_name = 'field'
 
 
+class FieldReservation(TargetdbBase):
+    field_id = IntegerField(null=False)
+
+    @classmethod
+    def requestNext(cls, N=1, commit=True, commissioning=False):
+        """inserts N new ids after max id and returns list of new ids"""
+        if commissioning:
+            next_id = cls.select(fn.MAX(cls.field_id))\
+                         .where(cls.field_id < 99999).scalar() + 1
+        else:
+            next_id = cls.select(fn.MAX(cls.field_id)).scalar() + 1
+        ids = [next_id + i for i in range(N)]
+        if commit:
+            db_format = [{"field_id": i} for i in ids]
+            cls.insert_many(db_format).execute()
+        return ids
+
+    class Meta:
+        table_name = 'field_reservation'
+
+
 class DesignMode(TargetdbBase):
     label = TextField(null=False)
     boss_skies_min = IntegerField(null=True)
@@ -143,11 +164,59 @@ class Design(TargetdbBase):
                                   null=True)
     mugatu_version = TextField()
     run_on = DateTimeField(default=datetime.datetime.now())
+    assignment_hash = UUIDField()
 
     class Meta:
         table_name = 'design'
 
 
+class DesignModeCheckResults(TargetdbBase):
+    pk = IntegerField(null=False, primary_key=True)
+    design = ForeignKeyField(Design,
+                             column_name='design_id',
+                             field='design_id',
+                             backref="design_mode_check_resultss")
+    # whether or not design passes recent
+    # validation and should be observed
+    design_pass = BooleanField(null=False)
+
+    # bitmask to describe current status of
+    # design validation
+    design_status = IntegerField(null=True)
+
+    # values and passing status for design-wide
+    # designmode criteria
+    boss_skies_min_pass = BooleanField(null=True)
+    boss_skies_min_value = IntegerField(null=True)
+    boss_skies_fov_pass = BooleanField(null=True)
+    boss_skies_fov_value = DoubleField(null=True)
+    apogee_skies_min_pass = BooleanField(null=True)
+    apogee_skies_min_value = IntegerField(null=True)
+    apogee_skies_fov_pass = BooleanField(null=True)
+    apogee_skies_fov_value = DoubleField(null=True)
+    boss_stds_min_pass = BooleanField(null=True)
+    boss_stds_min_value = IntegerField(null=True)
+    boss_stds_fov_pass = BooleanField(null=True)
+    boss_stds_fov_value = DoubleField(null=True)
+    apogee_stds_min_pass = BooleanField(null=True)
+    apogee_stds_min_value = IntegerField(null=True)
+    apogee_stds_fov_pass = BooleanField(null=True)
+    apogee_stds_fov_value = DoubleField(null=True)
+
+    # just passing status for target-specific
+    # designmode criteria
+    boss_stds_mags_pass = BooleanField(null=True)
+    apogee_stds_mags_pass = BooleanField(null=True)
+    boss_bright_limit_targets_pass = BooleanField(null=True)
+    apogee_bright_limit_targets_pass = BooleanField(null=True)
+    boss_sky_neighbors_targets_pass = BooleanField(null=True)
+    apogee_sky_neighbors_targets_pass = BooleanField(null=True)
+    apogee_trace_diff_targets_pass = BooleanField(null=True)
+
+    class Meta:
+        table_name = 'design_mode_check_results'
+
+
 class Instrument(TargetdbBase):
     label = TextField(null=True)
     pk = AutoField()
